==> mule-transport-file-1.3-rc5-sources.jar: org/mule/providers/file/filters/FilenameWildcardFilter.java <==
/*
 * $Id: FilenameWildcardFilter.java 3167 2006-09-22 15:47:04 +0000 (Fri, 22 Sep 2006) holger $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSource, Inc.  All rights reserved.  http://www.mulesource.com
 *
 * The software in this package is published under the terms of the MuleSource MPL
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.providers.file.filters;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.mule.providers.file.FileConnector;
import org.mule.routing.filters.WildcardFilter;
import org.mule.umo.UMOMessage;

import java.io.File;
import java.io.FilenameFilter;

/**
 * <code>FilenameWildcardFilter</code> Filters the incoming files from the
 * read From directory, based on file patterns
 * 
 * @author <a href="mailto:ross.mason@symphonysoft.com">Ross Mason</a>
 * @version $Revision: 3167 $
 */
public class FilenameWildcardFilter extends WildcardFilter implements FilenameFilter
{
    /**
     * logger used by this class
     */
    private static transient Log logger = LogFactory.getLog(FilenameWildcardFilter.class);

    public FilenameWildcardFilter()
    {
        super();
    }

    public FilenameWildcardFilter(String pattern)
    {
        super(pattern);
    }

    /**
     * UMOFilter condition decider method. <p/> Returns
     * <code>boolean</code> <code>TRUE</code> if the file conforms to an
     * acceptable pattern or <code>FALSE</code> otherwise.
     * 
     * @param dir The directory to apply the filter to.
     * @param name The name of the file to apply the filter to.
     * @return indication of acceptance as boolean.
     */
    public boolean accept(File dir, String name)
    {
        if (name == null) {
            logger.warn("The filename and or directory was null");
            return false;
        } else {
            return accept(name);
        }
    }
    
    public boolean accept(UMOMessage message)
    {
        return accept(message.getProperty(FileConnector.PROPERTY_ORIGINAL_FILENAME));
    }
}

==> mule-transport-file-1.3.2-sources.jar: org/mule/providers/file/filters/FilenameWildcardFilter.java <==
/*
 * $Id: FilenameWildcardFilter.java 3798 2006-11-04 04:07:14Z aperepel $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSource, Inc.  All rights reserved.  http://www.mulesource.com
 *
 * The software in this package is published under the terms of the MuleSource MPL
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.providers.file.filters;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.mule.providers.file.FileConnector;
import org.mule.routing.filters.WildcardFilter;
import org.mule.umo.UMOMessage;

import java.io.File;
import java.io.FilenameFilter;

/**
 * <code>FilenameWildcardFilter</code> Filters the incoming files from the read
 * From directory, based on file patterns.
 */
public class FilenameWildcardFilter extends WildcardFilter implements FilenameFilter
{
    /**
     * logger used by this class
     */
    private static Log logger = LogFactory.getLog(FilenameWildcardFilter.class);

    public FilenameWildcardFilter()
    {
        super();
    }

    public FilenameWildcardFilter(String pattern)
    {
        super(pattern);
    }

    /**
     * UMOFilter condition decider method. <p/> Returns
     * <code>boolean</code> <code>TRUE</code> if the file conforms to an
     * acceptable pattern or <code>FALSE</code> otherwise.
     * 
     * @param dir The directory to apply the filter to.
     * @param name The name of the file to apply the filter to.
     * @return indication of acceptance as boolean.
     */
    public boolean accept(File dir, String name)
    {
        if (name == null)
        {
            logger.warn("The filename and or directory was null");
            return false;
        }
        else
        {
            return accept(name);
        }
    }

    public boolean accept(UMOMessage message)
    {
        return accept(message.getProperty(FileConnector.PROPERTY_ORIGINAL_FILENAME));
    }
}
